summaryrefslogtreecommitdiffstats
path: root/components/html_viewer/html_viewer_switches.h
diff options
context:
space:
mode:
Diffstat (limited to 'components/html_viewer/html_viewer_switches.h')
-rw-r--r--components/html_viewer/html_viewer_switches.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/components/html_viewer/html_viewer_switches.h b/components/html_viewer/html_viewer_switches.h
index 68d6b6a..5b3b25d 100644
--- a/components/html_viewer/html_viewer_switches.h
+++ b/components/html_viewer/html_viewer_switches.h
@@ -8,8 +8,8 @@
namespace html_viewer {
namespace switches {
-// Switch to enable out of process iframes.
-extern const char kOOPIF[];
+// Switch to disable out of process iframes.
+extern const char kDisableOOPIF[];
// If true a new HTMLFrameTreeManager is always created, even if a matching
// HTMLFrameTreeManager is found. This is useful for tests (or debugging) that